@@ -1,5 +1,7 @@
 #! /usr/bin/tclsh
 
+cd [file dirname [info script]]
+
 lappend auto_path packages
 
 set rootuser ""
@@ -30,7 +32,9 @@ if {[file exists local/modules/autoload/onlyonce/siteconfig.tcl]} {
 	source local/modules/autoload/onlyonce/siteconfig.tcl
 }
 
-if {[info exists config::db(unconfigured)]} {
+namespace eval config {}
+
+if {![info exists config::db(user)] || ![info exists config::db(pass)] || ![info exists config::db(server)] || ![info exists config::db(dbname)]} {
 	puts -nonewline "DB Username: "
 	flush stdout
 	gets stdin config::db(user)
@@ -47,13 +51,13 @@ if {[info exists config::db(unconfigured)]} {
 	flush stdout
 	gets stdin config::db(dbname)
 
+	file mkdir "local/modules/autoload/onlyonce/"
 	set fd [open "local/modules/autoload/onlyonce/siteconfig.tcl" a+]
 	puts $fd "namespace eval ::config {"
 	puts $fd "	[list set db(user) $config::db(user)]"
 	puts $fd "	[list set db(pass) $config::db(pass)]"
 	puts $fd "	[list set db(server) $config::db(server)]"
 	puts $fd "	[list set db(dbname) $config::db(dbname)]"
-	puts $fd "	[list unset db(unconfigured)]"
 	puts $fd "}"
 	close $fd
 }
@@ -62,7 +66,7 @@ db::create -dbname sessions -fields [list sessionid data]
 db::create -dbname user -fields [list uid user name flags opts pass]
 db::create -dbname file -fields [list id name readperm writeperm]
 
-set manrootuid [uuid::gen user]
+set manrootuid [wa_uuid::gen user]
 db::set -dbname user -field uid $manrootuid -field user root -field flags [list root] -field pass "*LK*"
 user::setuid $manrootuid
 
